##  Mitigated Risk Percentage
The mitigated risk percentage view lets you track your progress in mitigating risks at the application level. It shows the percentage of IT components supporting each application with Risk Accepted or Risk Addressed statuses in the Obsolescence Risk Status field of the fact sheet. It helps you assess to what extent you have addressed and reduced risks.
  * Risk Accepted status indicates situations where you acknowledge the risks of outdated software or hardware as low and acceptable despite their persistence. This could apply to certain environments, such as testing or legacy systems.
  * Risk Addressed status indicates that the obsolescence risk was deemed unacceptable, and you are taking required actions, such as technology upgrades, migrating to another application or IT component, sunsetting the application, and so on.
![Obsolescence Risk Status of IT Component](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746acc37a4410149d02e8f2ab3f7430_LowRes.png)
Obsolescence Risk Status of IT Component


As a best practice, you would aim for 100% coverage of risk accepted or risk addressed to comprehensively manage risk across your application portfolio.
![Mitigated Risk Percentage View](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2745a2f57a441014b13acedecabd0444_LowRes.png)
Mitigated Risk Percentage View
